# Random Dot Patterns

Present static arrays of oriented objects where a proportion share a **coherent orientation** and the remainder are random; no coherent **motion** is present. Supports multiple apertures to show two arrays simultaneously for comparison or discrimination tasks.

## When To Use

- Orientation coherence tasks without motion.
- Two-array (dual aperture) comparisons.
- Varying orientation coherence to control difficulty.

## Example

Two random dot patterns are shown. The participant is asked to press 'y' the number of dots in the right pattern is not equal to the number of dots in the left pattern and 'n' if they are the same.

![weber fechner](../../img/stimuli/weber_fechner.png)

## Notes

Alias: **RDP**